@@ -12,7 +12,7 @@ use Scalar::Util qw(blessed refaddr);
 
 use constant RECURSION_LIMIT => $ENV{JSON_VALIDATOR_RECURSION_LIMIT} || 100;
 
-our $VERSION = '4.23';
+our $VERSION = '4.24';
 
 our %SCHEMAS = (
   'http://json-schema.org/draft-04/schema#'             => '+Draft4',
@@ -21,6 +21,7 @@ our %SCHEMAS = (
   'https://json-schema.org/draft/2019-09/schema'        => '+Draft201909',
   'http://swagger.io/v2/schema.json'                    => '+OpenAPIv2',
   'https://spec.openapis.org/oas/3.0/schema/2019-04-02' => '+OpenAPIv3',
+  'https://spec.openapis.org/oas/3.1/schema/2021-05-20' => '+OpenAPIv3',
 );
 
 has formats                   => sub { require JSON::Validator::Schema; JSON::Validator::Schema->_build_formats };
@@ -273,6 +274,10 @@ sub _new_schema {
     if ($spec->{swagger} and $spec->{swagger} eq '2.0') {
       $spec = 'http://swagger.io/v2/schema.json';
     }
+    elsif ($spec->{openapi} and $spec->{openapi} =~ m!^3\.1\.\d+$!) {
+      $spec = 'https://spec.openapis.org/oas/3.1/schema/2021-05-20';
+      $attrs{specification} ||= $spec;
+    }
     elsif ($spec->{openapi} and $spec->{openapi} =~ m!^3\.0\.\d+$!) {
       $spec = 'https://spec.openapis.org/oas/3.0/schema/2019-04-02';
     }
